# Kubeflow Utils

This is a simple Kubeflow utils package helping to speed up building ML model.

Features included:
- generate .docker/config.json for Kubeflow Fairing
- generate .kaggle/kaggle.json for Kaggle API
- download dataset through Kaggle API
